@@ -17,7 +17,7 @@ class UserService:
 
     def get_phone_number(self):
         """
-        获取当前授权帐号的手机号,特权接口仅部分帐号可以调用
+        获取当前授权账号的手机号,特权接口仅部分帐号可以调用
         """
         return self.__client.call("eleme.user.getPhoneNumber", {})
 
